pub struct UntrustedAdmissionRecoveryClaim { /* private fields */ }Expand description
Structurally checked claim returned by an admission-operation store.
This value is not authority and cannot be used to build a command until a qualified store rechecks it against durable operation and lease state.
Implementations
Sourceimpl UntrustedAdmissionRecoveryClaim
impl UntrustedAdmissionRecoveryClaim
pub fn new( operation_id: AdmissionOperationId, claimant_id: AdmissionIdentifier, coordinator_lease_id: AdmissionIdentifier, coordinator_lease_epoch: u64, claimed_version: u64, expires_at_unix_ms: u64, store_fence: StoreMutationFence, ) -> Result<Self, AdmissionOperationError>
pub fn operation_id(&self) -> &AdmissionOperationId
pub fn claimant_id(&self) -> &AdmissionIdentifier
pub fn coordinator_lease_id(&self) -> &AdmissionIdentifier
pub fn coordinator_lease_epoch(&self) -> u64
pub fn claimed_version(&self) -> u64
pub fn expires_at_unix_ms(&self) -> u64
pub fn store_fence(&self) -> &StoreMutationFence