Module authority

Module authority 

Structs

AuthoritySnapshot
AuthorityStatus
AuthorityTrustedKeySnapshot
LocalCapabilityAuthority

Enums

AuthorityStoreError

Traits

CapabilityAuthority

Functions

ensure_capability_issuance_supported
Validate that the local authority can issue the requested scope semantics.
validate_issued_capability_response
Validate that an authority response is exactly the direct capability requested.
validate_issued_capability_response_at
Deterministically validate an issuance response against the request and current authority.