pub struct CheckpointWitness {
pub log_id: String,
pub schema: String,
pub checkpoint_seq: u64,
pub checkpoint_sha256: String,
pub witness_checkpoint_seq: u64,
pub witness_checkpoint_sha256: String,
pub witnessed_at: u64,
}Expand description
A deterministic witness record derived from a checkpoint’s predecessor digest.
Fields
log_id: StringLocal log identity derived from the checkpoint signing key.
schema: StringSchema identifier for derived witness records.
checkpoint_seq: u64The checkpoint being witnessed.
checkpoint_sha256: StringCanonical SHA-256 digest of the witnessed checkpoint body.
witness_checkpoint_seq: u64The later checkpoint that cites the witnessed checkpoint digest.
witness_checkpoint_sha256: StringCanonical SHA-256 digest of the witness checkpoint body.
witnessed_at: u64Timestamp from the witness checkpoint body.