pub enum AttributeCardinality {
Low,
Bounded,
High,
}Expand description
Cardinality class for span attributes.
Variants
Low
Low-cardinality attribute with a small stable vocabulary.
Bounded
Bounded attribute whose value is dynamic but length capped.
High
Identifier attribute. Length is capped and values must not be used for aggregation dimensions without sampling.