pub struct PostInvocationHookIdentity { /* private fields */ }Expand description
Canonical implementation and configuration identity for a durable hook.
Implementations
Sourceimpl PostInvocationHookIdentity
impl PostInvocationHookIdentity
Sourcepub fn from_canonical_config<T: Serialize>(
component_id: impl Into<String>,
component_version: impl Into<String>,
implementation_tag: &str,
configuration: &T,
) -> Result<Self, String>
pub fn from_canonical_config<T: Serialize>( component_id: impl Into<String>, component_version: impl Into<String>, implementation_tag: &str, configuration: &T, ) -> Result<Self, String>
Bind an implementation tag and its complete effective configuration.
pub fn component_id(&self) -> &str
pub fn component_version(&self) -> &str
pub fn implementation_digest(&self) -> &str