pub struct RuntimeAdmissionContext<'a> {
pub request: &'a ToolCallRequest,
pub extra_metadata: Option<&'a Value>,
pub now_unix_secs: u64,
pub now_unix_ms: u64,
pub matched_grant_index: Option<usize>,
pub local_kernel_id: String,
}Expand description
Context passed to optional runtime admission hooks after capability, request matching, governed-admission, and guard checks pass, but before dispatch and federation co-signing side effects.
Fields
request: &'a ToolCallRequestextra_metadata: Option<&'a Value>now_unix_secs: u64now_unix_ms: u64matched_grant_index: Option<usize>local_kernel_id: StringAuto Trait Implementations
impl<'a> Freeze for RuntimeAdmissionContext<'a>
impl<'a> RefUnwindSafe for RuntimeAdmissionContext<'a>
impl<'a> Send for RuntimeAdmissionContext<'a>
impl<'a> Sync for RuntimeAdmissionContext<'a>
impl<'a> Unpin for RuntimeAdmissionContext<'a>
impl<'a> UnsafeUnpin for RuntimeAdmissionContext<'a>
impl<'a> UnwindSafe for RuntimeAdmissionContext<'a>