Structs
- Tool
Call Chunk - Streamed tool output emitted before the final tool response frame.
- Tool
Call Request - A tool call request as seen by the kernel.
- Tool
Call Response - The kernel’s response to a tool call request.
- Tool
Call Stream - Complete streamed output captured by the kernel.
- Tool
Invocation Cost - Cost reported by a tool server after invocation.
Enums
- Tool
Call Output - Output produced by a tool invocation.
- Tool
Server Event - Tool
Server Output - Tool-server output produced after validation and guard checks.
- Tool
Server Stream Result - Stream-capable tool-server result.
- Verdict
- Verdict of a guard or capability evaluation.
Traits
- Nested
Flow Bridge - Bridge exposed to tool-server implementations while a parent request is in flight.
- Nested
Flow Client - Raw client transport used by the kernel to service nested flows on behalf of a parent request.
- Tool
Server Connection - Trait representing a connection to a tool server.